==> entity_reference_modal-1.0.1.tar.gz: entity_reference_modal/src/Controller/EntityReferenceModalController.php <==
<?php

namespace Drupal\entity_reference_modal\Controller;

use Drupal\Core\Access\AccessResult;
use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\PageCache\ResponsePolicy\KillSwitch;
use Drupal\Core\Session\AccountInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\RequestStack;

/**
 * Returns responses for Entity reference modal routes.
 */
class EntityReferenceModalController extends ControllerBase {

  /**
   * The controller constructor.
   */
  public function __construct(protected KillSwitch $pageCacheKillSwitch, protected RequestStack $requestStack, protected $formBuilder) {

  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container): self {
    return new self(
      $container->get('page_cache_kill_switch'),
      $container->get('request_stack'),
      $container->get('form_builder'),
    );
  }

  /**
   * Builds the response.
   */
  public function build(Request $request, $entity_type, $bundle, $mode = 'default') {
    $this->pageCacheKillSwitch->trigger();
    $bundleKey = $this->entityTypeManager()->getDefinition($entity_type)
      ->getKey('bundle');
    $entity = $this->entityTypeManager->getStorage($entity_type)->create([
      $bundleKey => $bundle,
    ]);
    $form_mode = $request->query->get('mode');
    // @todo Fix problem custom form https://www.drupal.org/project/drupal/issues/2511720
    // Remove if $handler_type will be fixed.
    $handler_type = $this->entityTypeManager()
      ->getDefinition($entity_type, TRUE);
    $form_handlers = $handler_type->getHandlerClasses()['form'];
    if (!empty($form_mode)) {
      $mode = $form_mode;
      if (empty($form_handlers[$mode])) {
        $handler_type->setFormClass($mode, $form_handlers['default']);
      }
    }
    $form = $this->entityTypeManager()->getFormObject($entity_type, $mode)
      ->setEntity($entity);
    $form = $this->formBuilder->getForm($form);
    $form['#cache']['max-age'] = 0;
    return $form;
  }

  /**
   * Checks access for a specific request.
   *
   * @param \Drupal\Core\Session\AccountInterface $account
   *   Run access checks for this account.
   * @param string $entity_type
   *   Entity type.
   * @param string $bundle
   *   Bundle.
   * @param string $mode
   *   Mode default.
   *
   * @return \Drupal\Core\Access\AccessResultInterface
   *   The access result.
   */
  public function access(AccountInterface $account, $entity_type, $bundle, $mode = 'default') {
    $request = $this->requestStack->getCurrentRequest();
    $wrapper_format = $request->query->get('_wrapper_format');
    $drupal_ajax = $request->request->get('_drupal_ajax');
    if ($wrapper_format != 'drupal_modal' && $drupal_ajax != 1) {
      return AccessResult::forbidden();
    }
    $access_handler = $this->entityTypeManager()->getAccessControlHandler($entity_type);
    if ($bundle) {
      $access = $access_handler->createAccess($bundle);
    }
    else {
      $access = $access_handler->createAccess();
    }
    return AccessResult::allowedIf($access);
  }

}

==> entity_reference_modal-1.0.3.tar.gz: entity_reference_modal/src/Controller/EntityReferenceModalController.php <==
<?php

namespace Drupal\entity_reference_modal\Controller;

use Drupal\Core\Access\AccessResult;
use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\PageCache\ResponsePolicy\KillSwitch;
use Drupal\Core\Session\AccountInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\RequestStack;

/**
 * Returns responses for Entity reference modal routes.
 */
class EntityReferenceModalController extends ControllerBase {

  /**
   * The controller constructor.
   */
  public function __construct(protected KillSwitch $pageCacheKillSwitch, protected RequestStack $requestStack, protected $formBuilder) {

  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('page_cache_kill_switch'),
      $container->get('request_stack'),
      $container->get('form_builder'),
    );
  }

  /**
   * Builds the response.
   */
  public function build(Request $request, $entity_type, $bundle, $mode = 'default') {
    $this->pageCacheKillSwitch->trigger();
    $bundleKey = $this->entityTypeManager()->getDefinition($entity_type)
      ->getKey('bundle');
    $entity = $this->entityTypeManager->getStorage($entity_type)->create([
      $bundleKey => $bundle,
    ]);
    $form_mode = $request->query->get('mode');
    // @todo Fix problem custom form https://www.drupal.org/project/drupal/issues/2511720
    // Remove if $handler_type will be fixed.
    $handler_type = $this->entityTypeManager()
      ->getDefinition($entity_type, TRUE);
    $form_handlers = $handler_type->getHandlerClasses()['form'];
    if (!empty($form_mode)) {
      $mode = $form_mode;
      if (empty($form_handlers[$mode])) {
        $handler_type->setFormClass($mode, $form_handlers['default']);
      }
    }
    $form = $this->entityTypeManager()->getFormObject($entity_type, $mode)
      ->setEntity($entity);
    $form = $this->formBuilder->getForm($form);
    $form['#cache']['max-age'] = 0;
    return $form;
  }

  /**
   * Checks access for a specific request.
   *
   * @param \Drupal\Core\Session\AccountInterface $account
   *   Run access checks for this account.
   * @param string $entity_type
   *   Entity type.
   * @param string $bundle
   *   Bundle.
   * @param string $mode
   *   Mode default.
   *
   * @return \Drupal\Core\Access\AccessResultInterface
   *   The access result.
   */
  public function access(AccountInterface $account, $entity_type, $bundle, $mode = 'default') {
    $request = $this->requestStack->getCurrentRequest();
    $wrapper_format = $request->query->get('_wrapper_format');
    $drupal_ajax = $request->request->get('_drupal_ajax');
    if ($wrapper_format != 'drupal_modal' && $drupal_ajax != 1) {
      return AccessResult::forbidden();
    }
    $access_handler = $this->entityTypeManager()->getAccessControlHandler($entity_type);
    if ($bundle) {
      $access = $access_handler->createAccess($bundle);
    }
    else {
      $access = $access_handler->createAccess();
    }
    return AccessResult::allowedIf($access);
  }

}
